@@ -47,7 +47,7 @@ class Name:
     def __init__(
         self,
         name: str | None,
-        first_name: None,
+        first_name: None | str,
         last_name: str | None,
         type: str | None,
     ) -> None:
@@ -90,16 +90,14 @@ class Names(Name):
     def __init__(
         self,
         name: str | None,
-        first_name: None,
+        first_name: None | str,
         last_name: str | None,
         type: str | None,
     ) -> None:
         """
         Синоним для класса Name.
         """
-        super().__init__(
-            name=name, first_name=first_name, last_name=last_name, type=type
-        )
+        super().__init__(name=name, first_name=first_name, last_name=last_name, type=type)
 
 
 class Contact:
@@ -219,7 +217,7 @@ class StickerAttach:
     def __init__(
         self,
         author_type: str,
-        lottie_url: str,
+        lottie_url: str | None,
         url: str,
         sticker_id: int,
         tags: list[str] | None,
@@ -248,7 +246,7 @@ class StickerAttach:
     def from_dict(cls, data: dict[str, Any]) -> Self:
         return cls(
             author_type=data["authorType"],
-            lottie_url=data["lottieUrl"],
+            lottie_url=data.get("lottieUrl"),
             url=data["url"],
             sticker_id=data["stickerId"],
             tags=data.get("tags"),
@@ -443,9 +441,7 @@ class VideoAttach:
 
 
 class FileAttach:
-    def __init__(
-        self, file_id: int, name: str, size: int, token: str, type: AttachType
-    ) -> None:
+    def __init__(self, file_id: int, name: str, size: int, token: str, type: AttachType) -> None:
         self.file_id = file_id
         self.name = name
         self.size = size
@@ -553,9 +549,7 @@ class Me:
 
 
 class Element:
-    def __init__(
-        self, type: FormattingType | str, length: int, from_: int | None = None
-    ) -> None:
+    def __init__(self, type: FormattingType | str, length: int, from_: int | None = None) -> None:
         self.type = type
         self.length = length
         self.from_ = from_
@@ -566,9 +560,7 @@ class Element:
 
     @override
     def __repr__(self) -> str:
-        return (
-            f"Element(type={self.type!r}, length={self.length!r}, from_={self.from_!r})"
-        )
+        return f"Element(type={self.type!r}, length={self.length!r}, from_={self.from_!r})"
 
     @override
     def __str__(self) -> str:
@@ -591,7 +583,9 @@ class MessageLink:
 
     @override
     def __repr__(self) -> str:
-        return f"MessageLink(chat_id={self.chat_id!r}, message={self.message!r}, type={self.type!r})"
+        return (
+            f"MessageLink(chat_id={self.chat_id!r}, message={self.message!r}, type={self.type!r})"
+        )
 
     @override
     def __str__(self) -> str:
@@ -636,6 +630,36 @@ class ReactionInfo:
         )
 
 
+class ContactAttach:
+    def __init__(
+        self, contact_id: int, first_name: str, last_name: str, name: str, photo_url: str
+    ) -> None:
+        self.contact_id = contact_id
+        self.first_name = first_name
+        self.last_name = last_name
+        self.name = name
+        self.photo_url = photo_url
+        self.type = AttachType.CONTACT
+
+    @classmethod
+    def from_dict(cls, data: dict[str, Any]) -> Self:
+        return cls(
+            contact_id=data["contactId"],
+            first_name=data["firstName"],
+            last_name=data["lastName"],
+            name=data["name"],
+            photo_url=data["photoUrl"],
+        )
+
+    @override
+    def __repr__(self) -> str:
+        return f"ContactAttach(contact_id={self.contact_id!r}, first_name={self.first_name!r}, last_name={self.last_name!r}, name={self.name!r}, photo_url={self.photo_url!r})"
+
+    @override
+    def __str__(self) -> str:
+        return f"ContactAttach: {self.name}"
+
+
 class Message:
     def __init__(
         self,
@@ -658,6 +682,7 @@ class Message:
                 | ControlAttach
                 | StickerAttach
                 | AudioAttach
+                | ContactAttach
             ]
             | None
         ),
@@ -679,7 +704,13 @@ class Message:
     def from_dict(cls, data: dict[Any, Any]) -> Self:
         message = data["message"] if data.get("message") else data
         attaches: list[
-            PhotoAttach | VideoAttach | FileAttach | ControlAttach | StickerAttach
+            PhotoAttach
+            | VideoAttach
+            | FileAttach
+            | ControlAttach
+            | StickerAttach
+            | AudioAttach
+            | ContactAttach
         ] = []
         for a in message.get("attaches", []):
             if a["_type"] == AttachType.PHOTO:
@@ -694,6 +725,8 @@ class Message:
                 attaches.append(StickerAttach.from_dict(a))
             elif a["_type"] == AttachType.AUDIO:
                 attaches.append(AudioAttach.from_dict(a))
+            elif a["_type"] == AttachType.CONTACT:
+                attaches.append(ContactAttach.from_dict(a))
         link_value = message.get("link")
         if isinstance(link_value, dict):
             link = MessageLink.from_dict(link_value)
@@ -778,9 +811,7 @@ class Dialog:
             join_time=data["joinTime"],
             created=data["created"],
             last_message=(
-                Message.from_dict(data["lastMessage"])
-                if data.get("lastMessage")
-                else None
+                Message.from_dict(data["lastMessage"]) if data.get("lastMessage") else None
             ),
             type=ChatType(data["type"]),
             last_fire_delayed_error_time=data["lastFireDelayedErrorTime"],
@@ -865,14 +896,10 @@ class Chat:
     @classmethod
     def from_dict(cls, data: dict[Any, Any]) -> Self:
         raw_admins = data.get("adminParticipants", {}) or {}
-        admin_participants: dict[int, dict[Any, Any]] = {
-            int(k): v for k, v in raw_admins.items()
-        }
+        admin_participants: dict[int, dict[Any, Any]] = {int(k): v for k, v in raw_admins.items()}
         raw_participants = data.get("participants", {}) or {}
         participants: dict[int, int] = {int(k): v for k, v in raw_participants.items()}
-        last_msg = (
-            Message.from_dict(data["lastMessage"]) if data.get("lastMessage") else None
-        )
+        last_msg = Message.from_dict(data["lastMessage"]) if data.get("lastMessage") else None
         return cls(
             participants_count=data.get("participantsCount", 0),
             access=AccessType(data.get("access", AccessType.PUBLIC.value)),
@@ -1051,7 +1078,9 @@ class Session:
 
     @override
     def __str__(self) -> str:
-        return f"Session: {self.client} from {self.location} at {self.time} (current={self.current})"
+        return (
+            f"Session: {self.client} from {self.location} at {self.time} (current={self.current})"
+        )
 
 
 class Folder:
@@ -1164,3 +1193,28 @@ class FolderList:
     @override
     def __str__(self) -> str:
         return f"FolderList: {len(self.folders)} folders"
+
+
+class ReadState:
+    def __init__(
+        self,
+        unread: int,
+        mark: int,
+    ) -> None:
+        self.unread = unread
+        self.mark = mark
+
+    @classmethod
+    def from_dict(cls, data: dict[str, Any]) -> Self:
+        return cls(
+            unread=data["unread"],
+            mark=data["mark"],
+        )
+
+    @override
+    def __repr__(self) -> str:
+        return f"ReadState(unread={self.unread!r}, mark={self.mark!r})"
+
+    @override
+    def __str__(self) -> str:
+        return f"ReadState: unread={self.unread}, mark={self.mark}"
